lockedIndices property
Indices of children that cannot move while drag and drop.
Implementation
@visibleForTesting
var lockedIndices = <int>[];
Indices of children that cannot move while drag and drop.
@visibleForTesting
var lockedIndices = <int>[];