startDraggingScrollOffset property

  1. @visibleForTesting
Offset startDraggingScrollOffset
getter/setter pair

Saves the state of scroll Offset when the drag and drop is starting.

This is need to calculate with correct values later when doing drag and drop while scrolling and the scrolling is outside of ReorderableBuilder.

Implementation

@visibleForTesting
Offset startDraggingScrollOffset = Offset.zero;