ReorderableAnimationConfig class

Constructors

ReorderableAnimationConfig({Duration positionChangeDuration = const Duration(milliseconds: 200), Duration draggingPositionChangeDuration = const Duration(milliseconds: 200), Duration releasedItemDuration = const Duration(milliseconds: 150), Duration fadeInDuration = const Duration(milliseconds: 500), Duration dragFeedbackDuration = const Duration(milliseconds: 150), Curve? positionChangeCurve, Curve? draggingPositionChangeCurve, Curve? releasedItemCurve, Curve? fadeInCurve, Curve? dragFeedbackCurve, Curve? defaultAnimationCurve, bool enableAnimations = true})
const

Properties

defaultAnimationCurve Curve?
Global fallback curve for all curve parameters.
final
dragFeedbackCurve Curve
no setter
dragFeedbackDuration Duration
no setter
draggingPositionChangeCurve Curve?
no setter
draggingPositionChangeDuration Duration
no setter
enableAnimations bool
Whether animations are enabled.
final
fadeInCurve Curve?
no setter
fadeInDuration Duration
no setter
hashCode int
The hash code for this object.
no setterinherited
positionChangeCurve Curve?
no setter
positionChangeDuration Duration
no setter
releasedItemCurve Curve?
no setter
releasedItemDuration Duration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited