animationConfig property
Configuration for animations related the children.
These animations contains all kind of animations for the children, e.g. fade in or position animation.
Implementation
final ReorderableAnimationConfig animationConfig;
Configuration for animations related the children.
These animations contains all kind of animations for the children, e.g. fade in or position animation.
final ReorderableAnimationConfig animationConfig;