onReorder property
After releasing the dragged child, onReorder or onReorderPositions is called.
Ensure enableDraggable is set to true for this callback to trigger. This function takes a ReorderedListFunction as a parameter, which will reorder a list of items. Make sure to pass your list to this function and cast it afterward to your specific list type. This mechanism ensures that your list is correctly updated. You can then use the updated items returned by this function.
Implementation
final OnReorderCallback<T>? onReorder;