isScrollableOutside property
Defines if the scrollable part is outside of the widget.
The scrollable part can be a SingleChildScrollView that contains a GridView. In that case the GridView wouldn't be scrollable and this parameter should be true.
If the GridView is scrollable, then this will be true.
Implementation
@visibleForTesting
bool isScrollableOutside = false;